@@ -15,9 +15,12 @@
 from casdoor import CasdoorSDK
 from django.conf import settings
 from django.contrib.auth import authenticate, login
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 from django.shortcuts import redirect
 
+
+User = get_user_model()
+
 conf = settings.CASDOOR_CONFIG
 
 sdk = CasdoorSDK(conf.get('endpoint'),
